summaryrefslogtreecommitdiff
path: root/exercises/20_threads/threads2.rs
diff options
context:
space:
mode:
authormo8it <mo8it@proton.me>2024-07-05 13:39:50 +0200
committermo8it <mo8it@proton.me>2024-07-05 13:39:50 +0200
commit7123c7ae3a9605fbe962e4ef0a0f1424cd16fef8 (patch)
treec67f7e62bb9a179ae4fdbab492501cb6847e64c7 /exercises/20_threads/threads2.rs
parent77b687d501771c24bd83294d97b8e6f9ffa92d6b (diff)
parent4d9c346a173bb722b929f3ea3c00f84954483e24 (diff)
Merge remote-tracking branch 'upstream/main' into fix-enum-variant-inconsistency
Diffstat (limited to 'exercises/20_threads/threads2.rs')
-rw-r--r--exercises/20_threads/threads2.rs37
1 files changed, 16 insertions, 21 deletions
diff --git a/exercises/20_threads/threads2.rs b/exercises/20_threads/threads2.rs
index 62dad80..7020cb9 100644
--- a/exercises/20_threads/threads2.rs
+++ b/exercises/20_threads/threads2.rs
@@ -1,39 +1,34 @@
-// threads2.rs
-//
// Building on the last exercise, we want all of the threads to complete their
-// work but this time the spawned threads need to be in charge of updating a
-// shared value: JobStatus.jobs_completed
-//
-// Execute `rustlings hint threads2` or use the `hint` watch subcommand for a
-// hint.
+// work. But this time, the spawned threads need to be in charge of updating a
+// shared value: `JobStatus.jobs_done`
-// I AM NOT DONE
-
-use std::sync::Arc;
-use std::thread;
-use std::time::Duration;
+use std::{sync::Arc, thread, time::Duration};
struct JobStatus {
- jobs_completed: u32,
+ jobs_done: u32,
}
fn main() {
- let status = Arc::new(JobStatus { jobs_completed: 0 });
- let mut handles = vec![];
+ // TODO: `Arc` isn't enough if you want a **mutable** shared state.
+ let status = Arc::new(JobStatus { jobs_done: 0 });
+
+ let mut handles = Vec::new();
for _ in 0..10 {
let status_shared = Arc::clone(&status);
let handle = thread::spawn(move || {
thread::sleep(Duration::from_millis(250));
- // TODO: You must take an action before you update a shared value
- status_shared.jobs_completed += 1;
+
+ // TODO: You must take an action before you update a shared value.
+ status_shared.jobs_done += 1;
});
handles.push(handle);
}
+
+ // Waiting for all jobs to complete.
for handle in handles {
handle.join().unwrap();
- // TODO: Print the value of the JobStatus.jobs_completed. Did you notice
- // anything interesting in the output? Do you have to 'join' on all the
- // handles?
- println!("jobs completed {}", ???);
}
+
+ // TODO: Print the value of `JobStatus.jobs_done`.
+ println!("Jobs done: {}", todo!());
}